==> kubernetes-model-1.0.59-sources.jar: io/fabric8/openshift/api/model/ImageLayerBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class ImageLayerBuilder extends ImageLayerFluentImpl<ImageLayerBuilder> implements VisitableBuilder<ImageLayer,ImageLayerBuilder>{

    ImageLayerFluent<?> fluent;
    Boolean validationEnabled;

    public ImageLayerBuilder(){
            this(true);
    }
    public ImageLayerBuilder(Boolean validationEnabled){
            this(new ImageLayer(), validationEnabled);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent){
            this(fluent, true);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ImageLayer(), validationEnabled);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent,ImageLayer instance){
            this(fluent, instance, true);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent,ImageLayer instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withMediaType(instance.getMediaType()); 
            fluent.withName(instance.getName()); 
            fluent.withSize(instance.getSize()); 
            this.validationEnabled = validationEnabled; 
    }
    public ImageLayerBuilder(ImageLayer instance){
            this(instance,true);
    }
    public ImageLayerBuilder(ImageLayer instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withMediaType(instance.getMediaType()); 
            this.withName(instance.getName()); 
            this.withSize(instance.getSize()); 
            this.validationEnabled = validationEnabled; 
    }

    public ImageLayer build(){
            ImageLayer buildable = new ImageLayer(fluent.getMediaType(),fluent.getName(),fluent.getSize());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageLayerBuilder that = (ImageLayerBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/ImageLayerBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ImageLayerBuilder extends ImageLayerFluentImpl<ImageLayerBuilder> implements VisitableBuilder<ImageLayer,ImageLayerBuilder>{

    ImageLayerFluent<?> fluent;
    Boolean validationEnabled;

    public ImageLayerBuilder(){
            this(true);
    }
    public ImageLayerBuilder(Boolean validationEnabled){
            this(new ImageLayer(), validationEnabled);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent){
            this(fluent, true);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ImageLayer(), validationEnabled);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent,ImageLayer instance){
            this(fluent, instance, true);
    }
    public ImageLayerBuilder(ImageLayerFluent<?> fluent,ImageLayer instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withMediaType(instance.getMediaType()); 
            fluent.withName(instance.getName()); 
            fluent.withSize(instance.getSize()); 
            this.validationEnabled = validationEnabled; 
    }
    public ImageLayerBuilder(ImageLayer instance){
            this(instance,true);
    }
    public ImageLayerBuilder(ImageLayer instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withMediaType(instance.getMediaType()); 
            this.withName(instance.getName()); 
            this.withSize(instance.getSize()); 
            this.validationEnabled = validationEnabled; 
    }

    public ImageLayer build(){
            ImageLayer buildable = new ImageLayer(fluent.getMediaType(),fluent.getName(),fluent.getSize());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageLayerBuilder that = (ImageLayerBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
